import{d as o,o as a,a5 as s,f as d,u as c,S as _,_ as r}from"./jwt-decode.esm.7fb8faf4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c61cb7e5-b0ea-4c64-bc9f-0ee27f01f4d8",e._sentryDebugIdIdentifier="sentry-dbid-c61cb7e5-b0ea-4c64-bc9f-0ee27f01f4d8")}catch{}})();const f={class:"centered"},i=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",f,[d(c(_))]))}});const u=r(i,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.c883bb34.js.map
