import{d as b,e5 as f,eb as m,o as d,a as p,b as l,a5 as _,ec as g,f as y,e as v,ed as k,u as n,aR as w}from"./jwt-decode.esm.7fb8faf4.js";import{A as I,T}from"./Card.897ad69d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1d0cf457-3dd4-48b8-92e2-d12fb7da6de4",e._sentryDebugIdIdentifier="sentry-dbid-1d0cf457-3dd4-48b8-92e2-d12fb7da6de4")}catch{}})();const R=b({__name:"TablesTabs",setup(e){const a=f(),t=m(),u=String(t.name),c=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:c}})};return(o,D)=>(d(),p(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:l(()=>[(d(),_(w,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:l(()=>[v("span",null,k(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{R as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.1a057f69.js.map
