import{O as a}from"./OmniChat.de7b834a.js";import{u as s}from"./omniChatStore.83648f7c.js";import{d as c,eb as i,u as t,o as d,a as l,h as u}from"./jwt-decode.esm.7fb8faf4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="09c2a18a-1acd-4d19-a74a-a15fb54c47a6",e._sentryDebugIdIdentifier="sentry-dbid-09c2a18a-1acd-4d19-a74a-a15fb54c47a6")}catch{}})();const b=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=s();return o.init("console",n),(p,f)=>t(o).controller&&t(o).repository?(d(),l(a,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.99b3af8f.js.map
