import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.8e0a328b.js";import{d as i,eb as s,a,u as m,o as c}from"./jwt-decode.esm.7fb8faf4.js";import"./router.643f183e.js";import"./index.d928bc3c.js";import"./fetch.cbf466d2.js";import"./record.5fbe6782.js";import"./SaveButton.d14631e9.js";import"./ExclamationCircleOutlined.5510023c.js";import"./CrudView.d06da8d4.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a3f96825.js";import"./constants.60cb557d.js";import"./url.4e737b7f.js";import"./PhDotsThreeVertical.vue.377e8248.js";import"./index.3404e7dd.js";import"./asyncComputed.7b34952b.js";import"./omniChatStore.83648f7c.js";import"./uuid.0f9d5a19.js";import"./PhCopySimple.vue.b8cedde5.js";import"./PhPencil.vue.55f0d005.js";import"./useCodebaseEvents.28978c2b.js";import"./contracts.generated.6e0d1816.js";import"./index.09f330ad.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="55355c9e-1ae4-43e2-95a6-4874e18e21be",e._sentryDebugIdIdentifier="sentry-dbid-55355c9e-1ae4-43e2-95a6-4874e18e21be")}catch{}})();const A=i({__name:"EnvVars",setup(e){const r=s().params.projectId,t=new p(r);return(d,u)=>(c(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.afb25010.js.map
