import"./jwt-decode.esm.7fb8faf4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="029214bf-31ab-4883-8548-5f7e6495d992",e._sentryDebugIdIdentifier="sentry-dbid-029214bf-31ab-4883-8548-5f7e6495d992")}catch{}})();const f=(...e)=>window.fetch(...e);export{f as l};
//# sourceMappingURL=fetch.cbf466d2.js.map
