import{O as d}from"./workspaceStore.de299d82.js";import{d as i,J as l,a5 as c,f as a,b as n,u as o,o as u,g as r,A as f,da as p}from"./jwt-decode.esm.7fb8faf4.js";import"./userStore.f3109854.js";import"./url.4e737b7f.js";import"./colorHelpers.5dd0cb4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="81b1a665-d973-4f24-a69e-93e64f8c37ec",e._sentryDebugIdIdentifier="sentry-dbid-81b1a665-d973-4f24-a69e-93e64f8c37ec")}catch{}})();const g=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[r("You're authenticated")]),_:1}),a(o(p),null,{default:n(()=>[r(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLoginCallback.f56f78fc.js.map
