import{C as t,E as i,K as d,a as c,M as f,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.15446005.js";import"./jwt-decode.esm.7fb8faf4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="27f7e8c0-6b5a-4c8c-9526-bd44a5175c5e",e._sentryDebugIdIdentifier="sentry-dbid-27f7e8c0-6b5a-4c8c-9526-bd44a5175c5e")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,c as KeyMod,f as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.7f316986.js.map
