import{i as h}from"./metadata.bd2832f8.js";import{W as k}from"./Watermark.37fe047e.js";import{F as v}from"./PhArrowSquareOut.vue.6554aa1c.js";import{d as w,e5 as x,c as b,r as C,u as e,a5 as m,f as p,b as r,h as D,o as a,a as n,g as f,T as y,aR as I,ec as z,de as _,ef as T,ed as F,ea as B,_ as H}from"./jwt-decode.esm.7fb8faf4.js";import{u as L}from"./workspaceStore.de299d82.js";import"./index.f04176ea.js";import{L as N}from"./LoadingOutlined.f4b4629a.js";import{C as S}from"./Card.897ad69d.js";import"./PhUserList.vue.5cfe135b.js";import"./PhWebhooksLogo.vue.f667599c.js";import"./constants.60cb557d.js";import"./userStore.f3109854.js";import"./url.4e737b7f.js";import"./colorHelpers.5dd0cb4f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="47e69d4d-9d59-478d-a9d3-814d47330c3d",o._sentryDebugIdIdentifier="sentry-dbid-47e69d4d-9d59-478d-a9d3-814d47330c3d")}catch{}})();const V={key:0,class:"home-container"},W=w({__name:"Home",setup(o){const i=x(),d=L(),u=b(()=>{var s;return((s=d.state.workspace)==null?void 0:s.sidebar.filter(c=>c.id!=="home"))||[]}),l=C(null),g=async(s,c)=>{l.value=c,await i.push({path:`/${s}`}),l.value=null};return(s,c)=>e(d).state.workspace?(a(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(a(!0),m(I,{key:1},z(u.value,t=>(a(),n(e(S),{key:t.id,class:B(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(T(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(F(t.name),1)]),_:2},1024),l.value!==t.id?(a(),n(e(v),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(d).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Y=H(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.a001fbb0.js.map
