import{L as d}from"./Logo.648566b5.js";import{d as t,o as n,a as r,u as i}from"./jwt-decode.esm.7fb8faf4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="2954ead6-09bf-44b8-96dd-ded76f48a446",e._sentryDebugIdIdentifier="sentry-dbid-2954ead6-09bf-44b8-96dd-ded76f48a446")}catch{}})();const f="/assets/logo.0faadfa2.svg",b=t({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,a)=>{var o;return n(),r(d,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{b as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.23cf85ee.js.map
