import{O as d}from"./workspaceStore.de299d82.js";import{d as l,J as i,a5 as u,f as a,b as o,u as n,o as f,g as r,A as c,da as b}from"./jwt-decode.esm.7fb8faf4.js";import"./userStore.f3109854.js";import"./url.4e737b7f.js";import"./colorHelpers.5dd0cb4f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b3883c00-4f88-4daf-b5f5-0706c87d0bf8",e._sentryDebugIdIdentifier="sentry-dbid-b3883c00-4f88-4daf-b5f5-0706c87d0bf8")}catch{}})();const g=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(t,s)=>(f(),u("div",null,[a(n(c),null,{default:o(()=>[r("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[r(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLogoutCallback.437c4101.js.map
